<?php

class AfterSalesProGr_AcsPoints_Helper_Data extends Mage_Core_Helper_Abstract {

	protected $point_id;
	protected $point = [];

	public static function fetch_points_json( $force = true ) {
		$data = [
			'ACSAlias'           => 'ACS_Get_Stations_For_Plugin',
			'ACSInputParameters' => [
				'locale'           => null,
				'Company_ID'       => Mage::getStoreConfig( 'carriers/custom/acsCompanyID' ),
				'Company_Password' => Mage::getStoreConfig( 'carriers/custom/acsCompanyPassword' ),
				'User_ID'          => Mage::getStoreConfig( 'carriers/custom/acsUserID' ),
				'User_Password'    => Mage::getStoreConfig( 'carriers/custom/acsUserPassword' ),
			],
		];

		$client = new Varien_Http_Client( 'https://webservices.acscourier.net/ACSRestServices/api/ACSAutoRest' );
		$client->setMethod( Varien_Http_Client::POST );
		$client->setHeaders( array (
			'Accept'       => 'application/json',
			'Content-Type' => 'application/json',
			'ACSApiKey'    => Mage::getStoreConfig( 'carriers/custom/acsApiKey' ),
		) );
		$client->setRawData( json_encode( $data ), 'application/json' );
		$varien_response = $client->request();
		$response        = json_decode( $varien_response->getBody(), true );

        $points = $response['ACSOutputResponce']['ACSTableOutput']['Table_Data1'] ?? [];

        $points = array_values(array_filter($points, function ($item) {
            return $item['type'] !== 'branch' || $item['Acs_Station_Branch_Destination'] == '1';
        }));

		$data = [
			'status_code' => $varien_response->getStatus(),
			'meta'        => $response['ACSOutputResponce']['ACSTableOutput']['Table_Data'] ?? [],
			'points'      => $points,
		];

		file_put_contents( Mage::getBaseDir( 'media' ) . '/acs_points.json', json_encode( [
			'timestamp' => Mage::getModel('core/date')->gmtDate('Y-m-d H:i'),
			'meta'   => $response['ACSOutputResponce']['ACSTableOutput']['Table_Data'] ?? [],
			'points' => $points,
		], JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE ) );

		return $data;
	}

	public function getPointIcon() {
		return $this->getPointData( 'icon' );
	}

	protected function getPointData( $key ) {
		if ( $this->hasPoint() && array_key_exists( $key, $this->getAcsPoint() ) ) {
			return $this->getAcsPoint()[ $key ];
		}

		return null;
	}

	public function hasPoint() {
		return ! empty( $this->point_id ) && ! empty( $this->getAcsPoint() );
	}

	public function getAcsPoint() {
		if ( $this->point ) {
			return $this->point_id;
		}
		$data     = file_get_contents( Mage::getBaseDir( 'media' ) . '/acs_points.json' );
		$acs_data = json_decode( $data, true );
		if ( ! empty( $acs_data ) && ! empty( $acs_data['points'] ) ) {
			$index = array_column( $acs_data['points'], 'id' );
			$map   = array_flip( $index );
			$point = $acs_data['points'][ $map[ $this->point_id ] ?? null ] ?? false;
			if ( $point ) {
				$this->point_id = $point;

				return $this->point_id;
			}
		}

		return $this->point_id;
	}

	public function getPointName() {
		return $this->getPointData( 'name' );
	}

	public function getPointStreet() {
		return $this->getPointData( 'street' );
	}

	public function getPointMapUrl() {
		return "https://maps.google.com/?q={$this->getPointData('lat')},{$this->getPointData('lon')}";
	}

	public function setAcsPointId( $point_id ) {
		$this->point_id = $point_id;
		return $this;
	}
}
