<?php

class AfterSalesProGr_AcsPoints_Model_Carrier_Custom
    extends Mage_Shipping_Model_Carrier_Abstract
    implements Mage_Shipping_Model_Carrier_Interface
{
    protected $_code = 'custom';

    /**
     * Collect rates for this shipping method based on information in $request
     *
     * @param  Mage_Shipping_Model_Rate_Request  $data
     * @return Mage_Shipping_Model_Rate_Result
     */
    public function collectRates(Mage_Shipping_Model_Rate_Request $request)
    {
        $shipment_weight = 0;
        $shipment_price = 0;
        foreach ($request->getAllItems() as $item) {
            $shipment_weight += $item->getWeight();

            $tmpPrice = $item->getPrice();
            $shipment_price += $tmpPrice*$item->getQty();
        }

        if ($this->getConfigData('weightUpperLimit') > 0 && $shipment_weight > $this->getConfigData('weightUpperLimit')) {
            return false;
        }

        $isFreeShipping = $this->getConfigData('freeShippingUpperLimit') > 0 && $shipment_price >= $this->getConfigData('freeShippingUpperLimit');

        $methodPrice = 0;
        if (!$isFreeShipping) {
            $methodPrice = $this->getConfigData('basePrice');
        }

        $result = Mage::getModel('shipping/rate_result');
        $method = Mage::getModel('shipping/rate_result_method');
        $method->setCarrier($this->_code);
        $method->setCarrierTitle('ACS Points');
        $method->setMethod($this->_code);
        $method->setMethodTitle('');
        $method->setPrice($methodPrice);
        $method->setCost($methodPrice);
        $result->append($method);
        return $result;
    }

    /**
     * Get allowed shipping methods
     *
     * @return array
     */
    public function getAllowedMethods()
    {
        return array($this->_code => 'ACS Points');
    }
}
